@@ -21,12 +21,16 @@
 
 GPid rsync_pid;
 gint session_last = -1, initial_width, initial_height;
+gint root_x, root_y, width, height;
 // gint height_expander;
 gsize session_number = 0;
 gboolean had_error, paused, channel_closed, first_load_groups = TRUE, dryrunning = FALSE;
 gchar **groups = NULL, **argv, *error_list = NULL, *watch_oldfile = NULL;
 GtkWidget *rsync = NULL;
 gboolean config_output = FALSE, config_remember = TRUE, config_errorlist = FALSE, config_log = FALSE, config_fastscroll = TRUE;
+#ifndef MAEMO
+gboolean config_switchbutton = FALSE;
+#endif
 GTimeVal startime, pausedtime;
 gchar config_command[MAXPATH], *grsync_dir, *rsync_help = NULL, *rsync_man = NULL;
 FILE *log_file = NULL;
@@ -77,7 +81,6 @@ void set_main_title(gchar* session, gchar* extra) {
 void load_settings(gchar* session, gchar *filename) {
 	gchar settings_file_path[MAXPATH], *stmp;
 	GKeyFile *settings_file;
-	gint root_x, root_y, width, height;
 
 	if (filename == NULL) g_sprintf(settings_file_path, "%s/%s", grsync_dir, "grsync.ini");
 	else strncpy(settings_file_path, filename, MAXPATH-1);
@@ -116,6 +119,12 @@ void load_settings(gchar* session, gchar *filename) {
 		ini_get_boolean(settings_file, "errorlist", &config_errorlist);
 		ini_get_boolean(settings_file, "logging", &config_log);
 		ini_get_boolean(settings_file, "fastscroll", &config_fastscroll);
+#ifndef MAEMO
+		ini_get_boolean(settings_file, "switchbutton", &config_switchbutton);
+//		gtk_widget_set_visible((GtkWidget*) gtk_builder_get_object(builder, "button_switch"), config_switchbutton);  ONLY WORKS IN GTK 2.18
+		config_switchbutton ? gtk_widget_show((GtkWidget*) gtk_builder_get_object(builder, "button_switch")) :
+			gtk_widget_hide((GtkWidget*) gtk_builder_get_object(builder, "button_switch"));
+#endif
 
 		// load window position and size
 		root_x = g_key_file_get_integer(settings_file, CONFIG_GROUP, "root_x", NULL);
@@ -179,7 +188,6 @@ void save_settings(gchar *session, gchar *filename) {
 	FILE *key_file;
 	GError *error_handler = NULL;
 	GKeyFile *settings_file;
-	gint root_x, root_y, width, height;
 
 	if (filename == NULL) g_sprintf(settings_file_name, "%s/%s", grsync_dir, "grsync.ini");
 	else strncpy(settings_file_name, filename, MAXPATH-1);
@@ -198,11 +206,12 @@ void save_settings(gchar *session, gchar *filename) {
 		g_key_file_set_boolean(settings_file, CONFIG_GROUP, "errorlist", config_errorlist);
 		g_key_file_set_boolean(settings_file, CONFIG_GROUP, "logging", config_log);
 		g_key_file_set_boolean(settings_file, CONFIG_GROUP, "fastscroll", config_fastscroll);
+#ifndef MAEMO
+		g_key_file_set_boolean(settings_file, CONFIG_GROUP, "switchbutton", config_switchbutton);
+#endif
 		if (session_last != -1) g_key_file_set_string(settings_file, CONFIG_GROUP, "last_session", groups[session_last]);
 
 		// window position and size
-		gtk_window_get_position((GtkWindow*) main_window, &root_x, &root_y);
-		gtk_window_get_size((GtkWindow*) main_window, &width, &height);
 		g_key_file_set_integer(settings_file, CONFIG_GROUP, "root_x", root_x);
 		g_key_file_set_integer(settings_file, CONFIG_GROUP, "root_y", root_y);
 		g_key_file_set_integer(settings_file, CONFIG_GROUP, "width", width);
@@ -553,7 +562,6 @@ void on_main_create(GtkWindow *window, gpointer user_data) {
 	gchar *stmp;
 
 	grsync_dir = g_strconcat(g_get_home_dir(), "/.grsync", NULL);
-
 	if (!load_groups(argv_session)) {
 #ifndef MAEMO
 		error = gtk_message_dialog_new(window, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CANCEL,
@@ -613,6 +621,7 @@ void on_main_create(GtkWindow *window, gpointer user_data) {
 	rsync = (GtkWidget*) gtk_builder_get_object(builder, "dialog_rsync");
 	gtk_window_get_size((GtkWindow*) rsync, &initial_width, &initial_height);
 	if (cmdline_execute) on_play_clicked((GtkButton*) window, NULL);
+	if (cmdline_import) on_import1_activate((GtkMenuItem*) window, argv_filename);
 }
 
 
@@ -626,6 +635,13 @@ void on_main_destroy(GtkObject *object, gpointer user_data) {
 }
 
 
+gboolean on_main_configure_event(GtkWidget *widget, GdkEventConfigure *event, gpointer user_data) {
+		gtk_window_get_position((GtkWindow*) main_window, &root_x, &root_y);
+		gtk_window_get_size((GtkWindow*) main_window, &width, &height);
+		return FALSE;
+}
+
+
 void on_close_clicked(GtkButton *button, gpointer user_data) {
 	if (rsync_pid) {
 		if (paused) kill(rsync_pid, SIGCONT);
@@ -1034,9 +1050,33 @@ void on_session_del_clicked(GtkButton *button, gpointer user_data) {
 
 
 void on_button_about_clicked(GtkButton *button, gpointer user_data) {
-	gtk_show_about_dialog((GtkWindow*) main_window, "name", PACKAGE, "version", VERSION, "comments", _("A GTK GUI for rsync"),
-		"copyright", _("(C) Piero Orsoni and others. Released under the GPL.\nSee AUTHORS and COPYING for details"),
-		"website", "http://www.opbyte.it/grsync/", NULL);
+	gchar *artists[] = {
+		_("Application icons by Roberto Gadotti <info@kuama.net>"),
+		NULL
+	};
+
+	gchar *authors[] = {
+		_("Written by Piero Orsoni <orsoni@gmail.com>"),
+		_("Maemo compatibility by Luca Donaggio <donaggio@gmail.com>"),
+		_("Additional bug-fixing by Luca Marturana <lucamarturana@gmail.com>"),
+
+		_("Dutch translation by Frank de Bruijn <f.d.de.bruijn@gmail.com>"),
+		_("Simplified Chinese translation by Xie Yanbo <xieyanbo@gmail.com>"),
+		_("French translation by xavier <ersplus@free.fr>"),
+		_("Swedish translation by Daniel Nylander <info@danielnylander.se>"),
+		_("Turkish translation by Doruk Fisek <dfisek@fisek.com.tr>"),
+		_("Russian translation by Evgenii Terechkov <evg@altlinux.ru>"),
+		_("German translation by Martin Lettner <m.lettner@gmail.com>"),
+		_("Spanish translation by Ibon Castilla Varela <estri@euskalnet.net>"),
+		_("Czech translation by Martin Balajka <m.balajka@gmail.com>"),
+		_("Galician translation by Daniel Espinheira <daniel.espinheira@gmail.com>"),
+		_("Catalan translation by Josep Sànchez <josep.sanchez@ubuntu.cat>"),
+		NULL
+	};
+
+	gtk_show_about_dialog((GtkWindow*) main_window, "name", PACKAGE, "version", VERSION, "comments", _("Synchronize files and folders (a GTK GUI for rsync)."),
+		"copyright", _("(C) Piero Orsoni and others. Released under the GPL.\nSee COPYING for details"),
+		"website", "http://www.opbyte.it/grsync/", "artists", artists, "authors", authors, NULL);
 }
 
 
@@ -1083,6 +1123,9 @@ void on_preferences1_activate(GtkMenuItem *menuitem, gpointer user_data) {
 	set_checkbox("check_errorlist", config_errorlist);
 	set_checkbox("check_log", config_log);
 	set_checkbox("check_fastscroll", config_fastscroll);
+#ifndef MAEMO
+	set_checkbox("check_switchbutton", config_switchbutton);
+#endif
 	gtk_widget_show(config);
 
 	result = gtk_dialog_run((GtkDialog*) config);
@@ -1093,6 +1136,12 @@ void on_preferences1_activate(GtkMenuItem *menuitem, gpointer user_data) {
 		config_errorlist = get_checkbox("check_errorlist");
 		config_log = get_checkbox("check_log");
 		config_fastscroll = get_checkbox("check_fastscroll");
+#ifndef MAEMO
+		config_switchbutton = get_checkbox("check_switchbutton");
+//		gtk_widget_set_visible((GtkWidget*) gtk_builder_get_object(builder, "button_switch"), config_switchbutton);  ONLY WORKS IN GTK 2.18
+		config_switchbutton ? gtk_widget_show((GtkWidget*) gtk_builder_get_object(builder, "button_switch")) :
+			gtk_widget_hide((GtkWidget*) gtk_builder_get_object(builder, "button_switch"));
+#endif
 	}
 	gtk_widget_hide(config);
 }
@@ -1139,10 +1188,12 @@ void on_import1_activate(GtkMenuItem *menuitem, gpointer user_data) {
 	dialog = hildon_file_chooser_dialog_new ((GtkWindow*) main_window, GTK_FILE_CHOOSER_ACTION_OPEN);
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Browse"));
 #endif
-	retval = gtk_dialog_run (GTK_DIALOG (dialog));
+	if (user_data != NULL) gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(dialog), user_data);
+
+	retval = gtk_dialog_run(GTK_DIALOG(dialog));
 	if (retval == GTK_RESPONSE_ACCEPT || retval == GTK_RESPONSE_OK) {
 		gchar *filename;
-		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+		filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
 		load_settings(NULL, filename);
 
 #ifndef MAEMO
@@ -1155,7 +1206,7 @@ void on_import1_activate(GtkMenuItem *menuitem, gpointer user_data) {
 #endif
 		g_free(filename);
 	}
-	gtk_widget_destroy (dialog);
+	gtk_widget_destroy(dialog);
 }
 
 
